//******************************************************************************
//
//      CONTROLE DE POTENCIA POR MEIO DO METODO  PWM
//      Utiliza o comparador interno do pic.
//      (Verso com interrupo do timer 0).
//
//      Compara a tenso de um potenciometro com rampa gerada na carga de um
//      capacitor.
//      Frequencia de pwm ~ 500 hertz
//
//      Autor: Cludio Lrios
//      Data: 03/11/2014
//
//      Este arquivo  parte integrante do blog "LRIOS.TECNOLOGIA.WS'.
//      Obs. apenas para fins didticos.
//

//      PINAGENS:
//      pino 1 - +5v
//      pino 2 - desligado
//      pino 3 - desligado
//      pino 4 - desligado
//      pino 5 - sada pwm a um resistor de 470 a base do transistor npn. Emissor
//               ao gnd e coletor a carga a ser controlada (conforme corrente).
//      pino 6 - resistor de 100 ohms ao capacitor de 0.01uf (outro lado ao gnd)
//               e na mesma juno, um resitor de 100k ao +5v.
//      pino 7 - resistor de 330 ohms ao centro de um potenciometro, com extremo
//               para o gnd e outro para o +5v.
//
//
//==============================================================================


#include <12F675.h>
#device adc=8
#use delay(clock=4000000)// OSC INTERNO DE 4MHZ
#fuses NOWDT,INTRC_IO, NOCPD, NOPROTECT, NOMCLR, PUT, BROWNOUT //CONFIG WORD

//bytes
#byte CMCON      = 0X19
#byte gpio       = 0x05
#byte trisio     = 0x85

//bits
#bit  carga   = 0x05.1  //carrega capacitor



#int_timer0
void tmr0_isr(){
  
    carga=0;//DESCARREGA CAPACITOR
    trisio= 0b111001;//ACERTA PORTA PARA A DESCARGA
    cmcon=0x07;//DESLIGA COMPARADORES
    delay_us(20);//TEMPO DA DESCARGA
    trisio= 0b111011;//ACERTA SENTIDO DAS PORTAS
    cmcon=0x01;//ACERTA COMPARADOR PARA MODO DE TRABALHO

}

//==============================================================================
//           CONFIGURAES
//==============================================================================

void main() {

   setup_adc_ports(NO_ANALOGS|VSS_VDD);//DESLIGA COMPARADORES
   setup_adc(ADC_OFF);
   setup_counters(RTCC_INTERNAL,RTCC_DIV_4);//TIMER 0 /4
   setup_timer_1(T1_DISABLED); //DESABILITA TIMER 1
   setup_vref(FALSE);//DESLIGA VREF
   enable_interrupts(GLOBAL);
   enable_interrupts(INT_TIMER0);
   cmcon=0x01;//AJUSTA COMPARADORES PARA SAIDA EXTERNA
   gpio=0;//ZERA GPIO
   trisio= 0b111011; //ACERTA DIREO DOS PORTS


//==============================================================================
//    INICIO DO PROGRAMA
//==============================================================================

   for(;;){}  //loop infinito 
}
